## Product details

Discover the versatile Sterilite File Crate, your go-to solution for countless storage needs! Featuring carry-through handles, this plastic bin is ideal for both storing and transporting. Stack multiple crates to maximize vertical space or create bookcase-style shelving by stacking them sideways. This file tote can efficiently organize and store either letter or legal-sized hanging files, as well as office, school, household, and garage essentials like notebooks, albums, sports gear, and cleaning supplies. The File Crate is also a popular solution to keep college dorm room necessities organized and contained. The overall assembled dimensions of this item are 17 1/4" L x 14 1/4" W x 10 3/4" H.
Sterilite File Crate, Versatile Plastic Bin with Through Handles, Letter or Legal-sized File Storage, Stackable, Black
Outside Dimensions: 17 1/4" x 14 1/4" x 10 3/4"
Interior Dimensions at bottom: 15" x 12" x 10 1/4"
This versatile Sterilite plastic File Crate can be used throughout the home, office, dorm, garage, and utility areas
The ideal file tote organizer for keeping important paperwork sorted, neat, and contained
Conveniently accommodates either letter-size or legal-size file folders
Use multiple File Crates to create a customizable storage system
Modular design provides the flexibility of vertical and horizontal stacking options
Great for sorting and displaying albums and books in entertainments areas
Integrated carry-through handles make this a portable storage solution
BPA-free and phthalate-free
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

File & paper sorter & organizer type
File Tote Organizer
Height
10.75 in
Stackable
Y
Material
Plastic
More details
## Warranty

Warranty information
discontinue
